.. _config:

***************
Global Settings
***************

SunPy makes use of a settings file (:file:`sunpyrc`).
This file contains a number of global settings such as where files should be downloaded by default or the default format for displaying times.
When developing new functionality check this file and make use of the default values if appropriate or, if needed, define a new value.
More information can be found in :ref:`customizing-sunpy`.
